==> jc-1.4.0.tar.gz: soot/coffi/CoffiMethodSource.h <==
// public class soot.coffi.CoffiMethodSource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 72c3eb80c781a3b7 soot_coffi_CoffiMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_CoffiMethodSource_H_
#define _JC_soot_coffi_CoffiMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_coffi_ClassFile$object;
struct _jc_soot_coffi_method__5finfo$object;

// Typedefs
typedef struct _jc_soot_coffi_CoffiMethodSource$sub_refs	_jc_soot_coffi_CoffiMethodSource$sub_refs;
typedef struct _jc_soot_coffi_CoffiMethodSource$sub_nonrefs	_jc_soot_coffi_CoffiMethodSource$sub_nonrefs;
typedef struct _jc_soot_coffi_CoffiMethodSource$refs	_jc_soot_coffi_CoffiMethodSource$refs;
typedef struct _jc_soot_coffi_CoffiMethodSource$nonrefs	_jc_soot_coffi_CoffiMethodSource$nonrefs;
typedef struct _jc_soot_coffi_CoffiMethodSource$object	_jc_soot_coffi_CoffiMethodSource$object;

typedef const struct _jc_soot_coffi_CoffiMethodSource$vmethods	_jc_soot_coffi_CoffiMethodSource$vmethods;
typedef const struct _jc_soot_coffi_CoffiMethodSource$vtable	_jc_soot_coffi_CoffiMethodSource$vtable;
typedef const struct _jc_soot_coffi_CoffiMethodSource$vtype	_jc_soot_coffi_CoffiMethodSource$vtype;

// Constructors
extern void _jc_soot_coffi_CoffiMethodSource$method$_init$c865f42c2826f4f6(_jc_env *, struct _jc_soot_coffi_CoffiMethodSource$object *, struct _jc_soot_coffi_ClassFile$object *, struct _jc_soot_coffi_method__5finfo$object *);

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_coffi_CoffiMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_coffi_CoffiMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_CoffiMethodSource$method_info$getBody$01a871f1d690f082;

// Virtual methods structure
struct _jc_soot_coffi_CoffiMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_coffi_CoffiMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_coffi_CoffiMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_CoffiMethodSource$vmethods	soot_coffi_CoffiMethodSource;
};

// Vtype
struct _jc_soot_coffi_CoffiMethodSource$vtype {
	_jc_type			type;
	_jc_soot_coffi_CoffiMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_CoffiMethodSource$sub_refs {
	struct _jc_soot_coffi_ClassFile$object	*coffiClass;
	struct _jc_soot_coffi_method__5finfo$object	*coffiMethod;
};

// Reference instance fields (object)
struct _jc_soot_coffi_CoffiMethodSource$refs {
    _jc_soot_coffi_CoffiMethodSource$sub_refs	soot_coffi_CoffiMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_CoffiMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_CoffiMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_CoffiMethodSource$sub_nonrefs	soot_coffi_CoffiMethodSource;
};

// Object instance structure
struct _jc_soot_coffi_CoffiMethodSource$object {
	_jc_soot_coffi_CoffiMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_CoffiMethodSource$vtype	*vtype;
	_jc_soot_coffi_CoffiMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_CoffiMethodSource$vtype _jc_soot_coffi_CoffiMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_CoffiMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_CoffiMethodSource$class_object;

#endif	/* _JC_soot_coffi_CoffiMethodSource_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/CoffiMethodSource.h <==
// public class soot.coffi.CoffiMethodSource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 72c3eb80c781a3b7 soot_coffi_CoffiMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_CoffiMethodSource_H_
#define _JC_soot_coffi_CoffiMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_coffi_ClassFile$object;
struct _jc_soot_coffi_method__5finfo$object;

// Typedefs
typedef struct _jc_soot_coffi_CoffiMethodSource$sub_refs	_jc_soot_coffi_CoffiMethodSource$sub_refs;
typedef struct _jc_soot_coffi_CoffiMethodSource$sub_nonrefs	_jc_soot_coffi_CoffiMethodSource$sub_nonrefs;
typedef struct _jc_soot_coffi_CoffiMethodSource$refs	_jc_soot_coffi_CoffiMethodSource$refs;
typedef struct _jc_soot_coffi_CoffiMethodSource$nonrefs	_jc_soot_coffi_CoffiMethodSource$nonrefs;
typedef struct _jc_soot_coffi_CoffiMethodSource$object	_jc_soot_coffi_CoffiMethodSource$object;

typedef const struct _jc_soot_coffi_CoffiMethodSource$vmethods	_jc_soot_coffi_CoffiMethodSource$vmethods;
typedef const struct _jc_soot_coffi_CoffiMethodSource$vtable	_jc_soot_coffi_CoffiMethodSource$vtable;
typedef const struct _jc_soot_coffi_CoffiMethodSource$vtype	_jc_soot_coffi_CoffiMethodSource$vtype;

// Constructors
extern void _jc_soot_coffi_CoffiMethodSource$method$_init$c865f42c2826f4f6(_jc_env *, struct _jc_soot_coffi_CoffiMethodSource$object *, struct _jc_soot_coffi_ClassFile$object *, struct _jc_soot_coffi_method__5finfo$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_coffi_CoffiMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_coffi_CoffiMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_CoffiMethodSource$method_info$getBody$01a871f1d690f082;

// Virtual methods structure
struct _jc_soot_coffi_CoffiMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_coffi_CoffiMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_CoffiMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_CoffiMethodSource$vmethods	soot_coffi_CoffiMethodSource;
};

// Vtype
struct _jc_soot_coffi_CoffiMethodSource$vtype {
	_jc_type			type;
	_jc_soot_coffi_CoffiMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_CoffiMethodSource$sub_refs {
	struct _jc_soot_coffi_ClassFile$object	*coffiClass;
	struct _jc_soot_coffi_method__5finfo$object	*coffiMethod;
};

// Reference instance fields (object)
struct _jc_soot_coffi_CoffiMethodSource$refs {
    _jc_soot_coffi_CoffiMethodSource$sub_refs	soot_coffi_CoffiMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_CoffiMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_CoffiMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_CoffiMethodSource$sub_nonrefs	soot_coffi_CoffiMethodSource;
};

// Object instance structure
struct _jc_soot_coffi_CoffiMethodSource$object {
	_jc_soot_coffi_CoffiMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_CoffiMethodSource$vtype	*vtype;
	_jc_soot_coffi_CoffiMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_CoffiMethodSource$vtype _jc_soot_coffi_CoffiMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_CoffiMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_CoffiMethodSource$class_object;

#endif	/* _JC_soot_coffi_CoffiMethodSource_H_ */
